@@ -210,7 +210,7 @@ public:
    * For a non-memory input, the state nodes are equivalent to
    * physical nodes.
    */
-  void writePajekNetwork(std::string filename) const;
+  void writePajekNetwork(std::string filename, bool printFlow = false) const;
 
 protected:
   std::pair<NodeMap::iterator, bool> addStateNodeWithAutogeneratedId(unsigned int physId);
