@@ -30,52 +30,57 @@
 
 #include <map>
 #include <vector>
-#include <utility>
-#include "./Log.h"
-#include "../io/Config.h"
 
 namespace infomap {
 
+struct Config;
 class StateNetwork;
 
+namespace detail {
+  struct FlowLink {
+    unsigned int source;
+    unsigned int target;
+    double flow;
+  };
+} // namespace detail
+
 /**
  * Calculate flow on network based on different flow models
  */
 class FlowCalculator {
 public:
-  struct Link {
-    Link(unsigned int sourceIndex = 0, unsigned int targetIndex = 0, double weight = 0.0)
-        : source(sourceIndex),
-          target(targetIndex),
-          weight(weight),
-          flow(weight) {}
-
-    Link(const Link& other) = default;
-
-    unsigned int source;
-    unsigned int target;
-    double weight;
-    double flow;
-  };
-
-  using LinkVec = std::vector<Link>;
-
-  FlowCalculator() = default;
-  virtual ~FlowCalculator() = default;
-
-  virtual void calculateFlow(StateNetwork& network, const Config& config);
-
-  const std::vector<double>& getNodeFlow() const { return m_nodeFlow; }
-  const std::vector<double>& getNodeTeleportRates() const { return m_nodeTeleportRates; }
-  const LinkVec& getFlowLinks() const { return m_flowLinks; }
+  static void calculateFlow(StateNetwork& network, const Config &config) noexcept {
+    FlowCalculator f(network, config);
+  }
 
 protected:
-  void finalize(StateNetwork& network, const Config& config, bool normalizeNodeFlow = false);
+  FlowCalculator(StateNetwork&, const Config&);
 
-  std::map<unsigned int, unsigned int> m_nodeIndexMap;
-  std::vector<double> m_nodeFlow;
-  std::vector<double> m_nodeTeleportRates;
-  LinkVec m_flowLinks;
+  using FlowLink = detail::FlowLink;
+
+  void calcUndirectedFlow() noexcept;
+  void calcDirectedFlow(const StateNetwork&, const Config&) noexcept;
+  void calcDirectedBipartiteFlow(const StateNetwork&, const Config&) noexcept;
+  void calcDirdirFlow(const Config&) noexcept;
+  void calcRawdirFlow() noexcept;
+
+  void finalize(StateNetwork&, const Config&, bool) noexcept;
+
+  unsigned int numNodes;
+  unsigned int numLinks;
+  unsigned int nonDanglingStartIndex = 0;
+  unsigned int bipartiteStartIndex = 0;
+  unsigned int bipartiteLinkStartIndex = 0;
+
+  double sumLinkWeight;
+  double sumUndirLinkWeight;
+
+  std::map<unsigned int, unsigned int> nodeIndexMap;
+  std::vector<double> nodeFlow;
+  std::vector<double> nodeTeleportRates;
+  std::vector<double> sumLinkOutWeight;
+  std::vector<unsigned int> nodeOutDegree;
+  std::vector<FlowLink> flowLinks;
 };
 
 } // namespace infomap
