@@ -5,48 +5,34 @@
  *      Author: Daniel
  */
 
-#ifndef SRC_IO_LOG_H_
-#define SRC_IO_LOG_H_
+#ifndef _LOG_H_
+#define _LOG_H_
 
 #include <iostream>
 #include <limits>
 #include <iomanip>
+#include <type_traits>
 
 namespace infomap {
 
 struct hideIf;
 
 class Log {
+  using ostreamFuncPtr = std::add_pointer_t<std::ostream&(std::ostream&)>;
+
 public:
   /**
    * Log when level is below or equal Log::verboseLevel()
    * and maxLevel is above or equal Log::verboseLevel()
    */
-  explicit Log(unsigned int level = 0, unsigned int maxLevel = std::numeric_limits<unsigned int>::max())
-      : m_level(level),
-        m_maxLevel(maxLevel),
-        m_visible(levelVisible(m_level, m_maxLevel)),
-        m_ostream(getOutputStream(m_level, m_maxLevel)) {}
+  explicit Log(unsigned int level = 0, unsigned int maxLevel = std::numeric_limits<int>::max())
+      : m_level(level), m_maxLevel(maxLevel), m_visible(isVisible(m_level, m_maxLevel)) { }
 
-  explicit Log(const Log& other)
-      : m_level(other.m_level),
-        m_maxLevel(other.m_maxLevel),
-        m_visible(other.m_visible),
-        m_ostream(other.m_ostream) {}
+  bool isVisible() const { return isVisible(m_level, m_maxLevel); }
 
-  Log& operator=(const Log& other)
-  {
-    m_level = other.m_level;
-    m_maxLevel = other.m_maxLevel;
-    m_visible = other.m_visible;
-    return *this;
-  }
+  void hide(bool value) { m_visible = !value && isVisible(); }
 
-  bool levelVisible() const { return levelVisible(m_level, m_maxLevel); }
-
-  void hide(bool value) { m_visible = !value && levelVisible(); }
-
-  Log& operator<<(const hideIf& manip) { return *this; }
+  Log& operator<<(const hideIf&) { return *this; }
 
   template <typename T>
   Log& operator<<(const T& data)
@@ -56,7 +42,7 @@ public:
     return *this;
   }
 
-  Log& operator<<(std::ostream& (*f)(std::ostream&))
+  Log& operator<<(ostreamFuncPtr f)
   {
     if (m_visible)
       m_ostream << f;
@@ -70,15 +56,12 @@ public:
     Log() << std::setprecision(numberPrecision);
   }
 
-  static bool levelVisible(unsigned int level, unsigned int maxLevel)
+  static bool isVisible(unsigned int level, unsigned int maxLevel)
   {
     return !s_silent && s_verboseLevel >= level && s_verboseLevel <= maxLevel;
   }
 
-  static void setVerboseLevel(unsigned int level)
-  {
-    s_verboseLevel = level;
-  }
+  static void setVerboseLevel(unsigned int level) { s_verboseLevel = level; }
 
   static unsigned int verboseLevel() { return s_verboseLevel; }
 
@@ -86,11 +69,6 @@ public:
 
   static bool isSilent() { return s_silent; }
 
-  static std::ostream& getOutputStream(/* [[maybe_unused]] */ unsigned int level, /* [[maybe_unused]] */ unsigned int maxLevel)
-  {
-    return std::cout;
-  }
-
   static std::streamsize precision() { return std::cout.precision(); }
 
   static std::streamsize precision(std::streamsize precision)
@@ -102,14 +80,14 @@ private:
   unsigned int m_level;
   unsigned int m_maxLevel;
   bool m_visible;
-  std::ostream& m_ostream;
+  std::ostream& m_ostream = std::cout;
 
   static unsigned int s_verboseLevel;
   static bool s_silent;
 };
 
 struct hideIf {
-  explicit hideIf(bool value) : hide(value) {}
+  explicit hideIf(bool value) : hide(value) { }
 
   friend Log& operator<<(Log& out, const hideIf& manip)
   {
@@ -122,4 +100,4 @@ struct hideIf {
 
 } // namespace infomap
 
-#endif /* SRC_IO_LOG_H_ */
+#endif /* _LOG_H_ */
