@@ -322,6 +322,20 @@ void InfomapBase::run(Network& network)
 
   network.calculateFlow();
 
+  if (printFlowNetwork) {
+    std::string filename;
+    if (network.haveMemoryInput()) {
+      filename = outDirectory + outName + "_states_as_physical_flow.net";
+      Log() << "Writing flow state network as first order Pajek network to '" << filename << "'... ";
+    } else {
+      // Non-memory input
+      filename = outDirectory + outName + "_flow.net";
+      Log() << "Writing flow network to '" << filename << "'... ";
+    }
+    network.writePajekNetwork(filename, true);
+    Log() << "done!\n";
+  }
+
   if (network.isBipartite()) {
     bipartite = true;
   }
@@ -2102,7 +2116,7 @@ void InfomapBase::writeResult()
 
 
   if (printNewick) {
-    std::string filename = outDirectory + outName + ".tre";
+    std::string filename = outDirectory + outName + ".nwk";
 
     if (!haveMemory()) {
       Log() << "Write Newick tree to " << filename << "... ";
@@ -2113,13 +2127,32 @@ void InfomapBase::writeResult()
       Log() << "Write physical Newick tree to " << filename << "... ";
       writeNewickTree(filename, false);
       Log() << "done!\n";
-      std::string filenameStates = outDirectory + outName + "_states.tre";
+      std::string filenameStates = outDirectory + outName + "_states.nwk";
       Log() << "Write state Newick tree to " << filenameStates << "... ";
       writeNewickTree(filenameStates, true);
       Log() << "done!\n";
     }
   }
 
+  if (printJson) {
+    std::string filename = outDirectory + outName + ".json";
+
+    if (!haveMemory()) {
+      Log() << "Write JSON tree to " << filename << "... ";
+      writeJsonTree(filename);
+      Log() << "done!\n";
+    } else {
+      // Write both physical and state level
+      Log() << "Write physical JSON tree to " << filename << "... ";
+      writeJsonTree(filename, false);
+      Log() << "done!\n";
+      std::string filenameStates = outDirectory + outName + "_states.json";
+      Log() << "Write state JSON tree to " << filenameStates << "... ";
+      writeJsonTree(filenameStates, true);
+      Log() << "done!\n";
+    }
+  }
+
 
   if (printClu) {
     std::string filename = outDirectory + outName + ".clu";
@@ -2175,7 +2208,7 @@ std::string InfomapBase::writeFlowTree(std::string filename, bool states)
 
 std::string InfomapBase::writeNewickTree(std::string filename, bool states)
 {
-  std::string outputFilename = filename.empty() ? outDirectory + outName + (haveMemory() && states ? "_states.tre" : ".tre") : filename;
+  std::string outputFilename = filename.empty() ? outDirectory + outName + (haveMemory() && states ? "_states.nwk" : ".nwk") : filename;
 
   SafeOutFile outFile(outputFilename);
   writeNewickTree(outFile, states);
@@ -2183,6 +2216,16 @@ std::string InfomapBase::writeNewickTree(std::string filename, bool states)
   return outputFilename;
 }
 
+std::string InfomapBase::writeJsonTree(std::string filename, bool states)
+{
+  std::string outputFilename = filename.empty() ? outDirectory + outName + (haveMemory() && states ? "_states.json" : ".json") : filename;
+
+  SafeOutFile outFile(outputFilename);
+  writeJsonTree(outFile, states);
+
+  return outputFilename;
+}
+
 std::string InfomapBase::writeClu(std::string filename, bool states, int moduleIndexLevel)
 {
   // unsigned int maxModuleLevel = maxTreeDepth();
@@ -2484,6 +2527,107 @@ void InfomapBase::writeNewickTree(std::ostream& outStream, bool states)
   outStream << std::setprecision(oldPrecision);
 }
 
+void InfomapBase::writeJsonTree(std::ostream& outStream, bool states)
+{
+  auto oldPrecision = outStream.precision();
+
+  outStream << "{\n";
+
+  outStream << "  \"version\": \"v" << INFOMAP_VERSION << "\",\n"
+            << "  \"args\": \"" << parsedString << "\",\n"
+            << "  \"startedAt\": \"" << m_startDate << "\",\n"
+            << "  \"completedIn\": " << m_elapsedTime.getElapsedTimeInSec() << ",\n"
+            << "  \"numLevels\": " << maxTreeDepth() << ",\n"
+            << "  \"numTopModules\": " << numTopModules() << ",\n"
+            << "  \"codelength\": " << codelength() << ",\n"
+            << "  \"relativeCodelengthSavings\": " << getRelativeCodelengthSavings() << ",\n";
+
+  if (isBipartite()) {
+    outStream << "  \"bipartiteStartId\": " << m_network.bipartiteStartId() << ",\n";
+  }
+
+  outStream << std::setprecision(6);
+
+  outStream << "  \"nodes\": [\n";
+
+  const auto nodeName = [this](const auto& node) {
+      auto name = m_network.names()[node.physicalId];
+
+      if (name.empty()) {
+        name = io::stringify(node.physicalId);
+      }
+
+      return name;
+  };
+
+  const auto shouldHideBipartiteNodes = isBipartite() && hideBipartiteNodes;
+  const auto bipartiteStartId = shouldHideBipartiteNodes ? m_network.bipartiteStartId() : 0;
+
+  // don't append a comma after the last entry
+  auto first = true;
+
+  if (haveMemory() && !states) {
+    for (auto it(iterTreePhysical()); !it.isEnd(); ++it) {
+      InfoNode& node = *it;
+      if (node.isLeaf()) {
+        if (shouldHideBipartiteNodes && node.physicalId >= bipartiteStartId) {
+          continue;
+        }
+
+        const auto path = io::stringify(it.path(), ", ");
+
+        if (first) {
+          first = false;
+        } else {
+          outStream << ",\n";
+        }
+
+        outStream << "    { ";
+        outStream << "\"path\": [" << path << "], ";
+        outStream << "\"name\": \"" << nodeName(node) << "\", ";
+        outStream << "\"flow\": " << node.data.flow << ", ";
+        outStream << "\"id\": " << node.physicalId << " }";
+      }
+    }
+  } else {
+    for (auto it(iterTree()); !it.isEnd(); ++it) {
+      InfoNode& node = *it;
+      if (node.isLeaf()) {
+        if (shouldHideBipartiteNodes && node.physicalId >= bipartiteStartId) {
+          continue;
+        }
+
+        if (first) {
+          first = false;
+        } else {
+          outStream << ",\n";
+        }
+
+        const auto path = io::stringify(it.path(), ", ");
+
+        outStream << "    { ";
+        outStream << "\"path\": [" << path << "], ";
+        outStream << "\"name\": \"" << nodeName(node) << "\", ";
+        outStream << "\"flow\": " << node.data.flow << ", ";
+
+        if (states) {
+          outStream << "\"stateId\": " << node.stateId << ", ";
+          if (isMultilayerNetwork())
+            outStream << "\"layerId\": " << node.layerId << ", ";
+        }
+
+        outStream << "\"id\": " << node.physicalId << " }";
+      }
+    }
+  }
+
+  outStream << "\n  ]\n"; // tree
+  outStream << '}';
+
+  outStream << std::setprecision(oldPrecision);
+}
+
+
 unsigned int InfomapBase::printPerLevelCodelength(std::ostream& out)
 {
   std::vector<PerLevelStat> perLevelStats;
