@@ -75,7 +75,7 @@ Config::Config(std::string flags, bool isCLI) : isCLI(isCLI)
   // 		"Print the network with calculated flow values.", "Output", true);
 
   // -o network,states,clu,ftree
-  api.addOptionArgument(outputFormats, 'o', "output", "Comma-separated output formats without spaces, e.g. -o clu,tree,ftree. Options: clu, tree, ftree, newick, network, states.", ArgType::list, "Output", true);
+  api.addOptionArgument(outputFormats, 'o', "output", "Comma-separated output formats without spaces, e.g. -o clu,tree,ftree. Options: clu, tree, ftree, newick, json, network, states, flow.", ArgType::list, "Output", true);
 
   api.addOptionArgument(hideBipartiteNodes, "hide-bipartite-nodes", "Project bipartite solution to unipartite.", "Output", true);
 
@@ -251,8 +251,12 @@ void Config::adaptDefaults()
       printFlowTree = true;
     } else if (o == "newick") {
       printNewick = true;
+    } else if (o == "json") {
+      printJson = true;
     } else if (o == "network") {
       printPajekNetwork = true;
+    } else if (o == "flow") {
+      printFlowNetwork = true;
     } else if (o == "states") {
       printStateNetwork = true;
     } else {
@@ -271,8 +275,6 @@ void Config::adaptDefaults()
 inline const char* flowModelToString(FlowModel flowModel)
 {
   switch (flowModel) {
-  case FlowModel::undirected:
-    return "undirected";
   case FlowModel::directed:
     return "directed";
   case FlowModel::undirdir:
@@ -281,6 +283,9 @@ inline const char* flowModelToString(FlowModel flowModel)
     return "outdirdir";
   case FlowModel::rawdir:
     return "rawdir";
+  case FlowModel::undirected:
+  default:
+    return "undirected";
   }
 }
 
